@@ -14,7 +14,7 @@
 /**********************/
 
 #define PROGRAMNAME          "snaphu"
-#define VERSION              "2.0.4"
+#define VERSION              "2.0.5"
 #define BUGREPORTEMAIL       "snaphu@gmail.com"
 #ifdef PI
 #undef PI
@@ -45,7 +45,7 @@
 #define BOUNDARYCANDIDATE    -7
 #define BOUNDARYLEVEL        LARGEINT
 #define INTERIORLEVEL        (BOUNDARYLEVEL-1)
-#define MINBOUNDARYSIZE      3
+#define MINBOUNDARYSIZE      100
 #define POSINCR              0
 #define NEGINCR              1
 #define NOCOSTSHELF          -LARGESHORT
@@ -790,7 +790,7 @@ int InitNodes(long nrow, long ncol, nodeT **nodes, nodeT *ground);
 void BucketInsert(nodeT *node, long ind, bucketT *bkts);
 void BucketRemove(nodeT *node, long ind, bucketT *bkts);
 nodeT *ClosestNode(bucketT *bkts);
-long SelectSources(nodeT **nodes, nodeT *ground, long nflow, 
+long SelectSources(nodeT **nodes, float **mag, nodeT *ground, long nflow, 
                    short **flows, long ngroundarcs, 
                    long nrow, long ncol, paramT *params,
                    nodeT ***sourcelistptr, long **nconnectedarrptr);
